The panel verion of the observational part of the
lalonde dataset. It
is loaded with all the datasets with the command data(lalonde)
The panel verion of the observational part of the
lalonde dataset. It
is loaded with all the datasets with the command data(lalonde)