Learn R Programming

qte (version 2.0.0)

lalonde.psid: Lalonde's Observational Dataset

Description

The cross sectional verion of the observational part of the lalonde dataset. It is loaded with all the datasets with the command data(lalonde)

Arguments