Learn R Programming

qte (version 2.0.0)

lalonde.psid.panel: Lalonde's Panel Observational Dataset

Description

The panel verion of the observational part of the lalonde dataset. It is loaded with all the datasets with the command data(lalonde)

Arguments